Groups | Search | Server Info | Keyboard shortcuts | Login | Register [http] [https] [nntp] [nntps]


Groups > linux.debian.user > #206296 > unrolled thread

youtube video downloader for chrome

Started byPierre Frenkiel <pierre.frenkiel@gmail.com>
First post2019-03-18 11:10 +0100
Last post2019-03-24 12:20 +0100
Articles 9 on this page of 29 — 10 participants

Back to article view | Back to linux.debian.user


Contents

  youtube video downloader for chrome Pierre Frenkiel <pierre.frenkiel@gmail.com> - 2019-03-18 11:10 +0100
    Re: youtube video downloader for chrome David <bouncingcats@gmail.com> - 2019-03-18 12:30 +0100
      Re: youtube video downloader for chrome Pierre Frenkiel <pierre.frenkiel@gmail.com> - 2019-03-18 12:40 +0100
        Re: youtube video downloader for chrome Carl Fink <carl@finknetwork.com> - 2019-03-18 14:50 +0100
          Re: youtube video downloader for chrome riveravaldez <riveravaldezmail@gmail.com> - 2019-03-20 00:00 +0100
            Re: youtube video downloader for chrome Pierre Frenkiel <pierre.frenkiel@gmail.com> - 2019-03-20 10:40 +0100
              Re: youtube video downloader for chrome Brad Rogers <brad@fineby.me.uk> - 2019-03-20 11:30 +0100
              Re: youtube video downloader for chrome Greg Wooledge <wooledg@eeg.ccf.org> - 2019-03-20 13:10 +0100
                Re: youtube video downloader for chrome David Wright <deblis@lionunicorn.co.uk> - 2019-03-20 19:20 +0100
                  Re: youtube video downloader for chrome rhkramer@gmail.com - 2019-03-20 20:10 +0100
                    Re: youtube video downloader for chrome Celejar <celejar@gmail.com> - 2019-03-20 23:30 +0100
                      Re: youtube video downloader for chrome David Wright <deblis@lionunicorn.co.uk> - 2019-03-23 02:00 +0100
                        Re: youtube video downloader for chrome Celejar <celejar@gmail.com> - 2019-03-25 03:20 +0100
                    Re: youtube video downloader for chrome David Wright <deblis@lionunicorn.co.uk> - 2019-03-21 01:30 +0100
                      Re: youtube video downloader for chrome rhkramer@gmail.com - 2019-03-21 03:20 +0100
                Re: youtube video downloader for chrome Pierre Frenkiel <pierre.frenkiel@gmail.com> - 2019-03-20 19:20 +0100
              Re: youtube video downloader for chrome Celejar <celejar@gmail.com> - 2019-03-20 23:20 +0100
                Re: youtube video downloader for chrome Pierre Frenkiel <pierre.frenkiel@gmail.com> - 2019-03-21 15:40 +0100
                  Re: youtube video downloader for chrome David Wright <deblis@lionunicorn.co.uk> - 2019-03-21 16:50 +0100
                    Re: youtube video downloader for chrome Fred <fred@blakemfg.com> - 2019-03-21 18:40 +0100
                      Re: youtube video downloader for chrome Pierre Frenkiel <pierre.frenkiel@gmail.com> - 2019-03-21 20:00 +0100
                      Re: youtube video downloader for chrome David Wright <deblis@lionunicorn.co.uk> - 2019-03-21 20:00 +0100
                        Re: youtube video downloader for chrome Fred <fred@blakemfg.com> - 2019-03-21 22:50 +0100
                          Re: youtube video downloader for chrome Greg Wooledge <wooledg@eeg.ccf.org> - 2019-03-22 13:10 +0100
                            Re: youtube video downloader for chrome Fred <fred@blakemfg.com> - 2019-03-22 15:20 +0100
                          Re: youtube video downloader for chrome David Wright <deblis@lionunicorn.co.uk> - 2019-03-23 02:10 +0100
                            Re: youtube video downloader for chrome Pierre Frenkiel <pierre.frenkiel@gmail.com> - 2019-03-23 20:20 +0100
                              Re: youtube video downloader for chrome David Wright <deblis@lionunicorn.co.uk> - 2019-03-24 17:10 +0100
                Re: youtube video downloader for chrome Pierre Frenkiel <pierre.frenkiel@gmail.com> - 2019-03-24 12:20 +0100

Page 2 of 2 — ← Prev page 1 [2]


#206439

FromPierre Frenkiel <pierre.frenkiel@gmail.com>
Date2019-03-21 20:00 +0100
Message-ID<xEb4Z-5A0-11@gated-at.bofh.it>
In reply to#206433
On Thu, 21 Mar 2019, Fred wrote:

> I think you would be better off with:
>
> youtube-dl --update
>


==> youtube-dl --update
It looks like you installed youtube-dl with a package manager, pip, setup.py or a tarball. Please use that to update.

[toc] | [prev] | [next] | [standalone]


#206440

FromDavid Wright <deblis@lionunicorn.co.uk>
Date2019-03-21 20:00 +0100
Message-ID<xEb50-5A0-13@gated-at.bofh.it>
In reply to#206433
On Thu 21 Mar 2019 at 10:17:11 (-0700), Fred wrote:
> On 03/21/2019 08:41 AM, David Wright wrote:
> > On Thu 21 Mar 2019 at 15:38:41 (+0100), Pierre Frenkiel wrote:
> > > On Wed, 20 Mar 2019, Celejar wrote:
> > > > On Wed, 20 Mar 2019 10:34:42 +0100 (CET) Pierre Frenkiel <pierre.frenkiel@gmail.com> wrote:
> > > > > On Tue, 19 Mar 2019, riveravaldez wrote:
> > > > > 
> > > > > > Maybe worth mentioning: youtube-dl, exceptionally useful and simple CLI tool.
> > > > >     useful and simple... but it works only for urls with alphanumeric characters
> > > > >     I tried with an url containing ? and &, and I got nothing
> > > > >     I tried also by escaping ? and & with \, and it was not better.
> > > > >     I'll send you an example later, if you are not convinced...
> > > > You can also try putting the url(s) in a file, and feeding the file to
> > > > youtube-dl via its -a option.
> > > > 
> > > > Celejar
> > > > 
> > >    At last, I fixed everything just by loadind the last version of youtube-dl from the
> > >    yt-dl site
> > >        wget https://yt-dl.org/latest/youtube-dl -O /usr/local/bin/youtube-dl
> > > 
> > > after that,  I can do either
> > >      youtube-dl --no-playlist  'https://www.youtube.com/watch?v=VQd1IOyhKS4&list=RDEMlHFFKeq-aYlBhg-LtJ-SHw&start_radio=1'
> > >      or
> > >     youtube-dl https://www.youtube.com/watch?v=VQd1IOyhKS4 both give
> > > exactly the same result.
> > > 
> > > My question is why the Debian version so obsolte ans uneliable?
> > The latest version on the website is three days old. The version I
> > installed from backports on Jan 28 was 11 days old.
> > 
> > You have to understand that sites like youtube and the BBC can
> > obsolete youtube-dl and get_iplayer overnight, and they do.
> > Then some clever people come up with a fix and release a new
> > version, and I heave a big sigh of relief and thanks. (Most
> > BBC programmes expire after four weeks, and I'm usually two or
> > three weeks behind, so a quick fix is vital.)
> > 
> > Debian mainstream doesn't work to that timetable, so you should
> > check out the backports, where those sorts of package appear.
> > Fortunately, get_iplayer is a single Perl script so I just
> > download it from its site and put it in ~/bin, as you can see
> > from my examples.
> > 
> Hi,
> I think you would be better off with:
> 
> youtube-dl --update

a) Why?

b) How?

$ youtube-dl --update
Usage: youtube-dl [OPTIONS] URL [URL...]

youtube-dl: error: youtube-dl's self-update mechanism is disabled on Debian.
Please update youtube-dl using apt(8).
See https://packages.debian.org/sid/youtube-dl for the latest packaged version.

$ 

> also:
> 
>  youtube-dl --help
> 
> will show all the options.

… and, of course, --update is missing.

But which of these options did you mean to draw my attention to?

Cheers,
David.

[toc] | [prev] | [next] | [standalone]


#206442

FromFred <fred@blakemfg.com>
Date2019-03-21 22:50 +0100
Message-ID<xEdJv-7h2-5@gated-at.bofh.it>
In reply to#206440
On 03/21/2019 11:57 AM, David Wright wrote:
> On Thu 21 Mar 2019 at 10:17:11 (-0700), Fred wrote:
>> On 03/21/2019 08:41 AM, David Wright wrote:
>>> On Thu 21 Mar 2019 at 15:38:41 (+0100), Pierre Frenkiel wrote:
>>>> On Wed, 20 Mar 2019, Celejar wrote:
>>>>> On Wed, 20 Mar 2019 10:34:42 +0100 (CET) Pierre Frenkiel <pierre.frenkiel@gmail.com> wrote:
>>>>>> On Tue, 19 Mar 2019, riveravaldez wrote:
>>>>>>
>>>>>>> Maybe worth mentioning: youtube-dl, exceptionally useful and simple CLI tool.
>>>>>>      useful and simple... but it works only for urls with alphanumeric characters
>>>>>>      I tried with an url containing ? and &, and I got nothing
>>>>>>      I tried also by escaping ? and & with \, and it was not better.
>>>>>>      I'll send you an example later, if you are not convinced...
>>>>> You can also try putting the url(s) in a file, and feeding the file to
>>>>> youtube-dl via its -a option.
>>>>>
>>>>> Celejar
>>>>>
>>>>     At last, I fixed everything just by loadind the last version of youtube-dl from the
>>>>     yt-dl site
>>>>         wget https://yt-dl.org/latest/youtube-dl -O /usr/local/bin/youtube-dl
>>>>
>>>> after that,  I can do either
>>>>       youtube-dl --no-playlist  'https://www.youtube.com/watch?v=VQd1IOyhKS4&list=RDEMlHFFKeq-aYlBhg-LtJ-SHw&start_radio=1'
>>>>       or
>>>>      youtube-dl https://www.youtube.com/watch?v=VQd1IOyhKS4 both give
>>>> exactly the same result.
>>>>
>>>> My question is why the Debian version so obsolte ans uneliable?
>>> The latest version on the website is three days old. The version I
>>> installed from backports on Jan 28 was 11 days old.
>>>
>>> You have to understand that sites like youtube and the BBC can
>>> obsolete youtube-dl and get_iplayer overnight, and they do.
>>> Then some clever people come up with a fix and release a new
>>> version, and I heave a big sigh of relief and thanks. (Most
>>> BBC programmes expire after four weeks, and I'm usually two or
>>> three weeks behind, so a quick fix is vital.)
>>>
>>> Debian mainstream doesn't work to that timetable, so you should
>>> check out the backports, where those sorts of package appear.
>>> Fortunately, get_iplayer is a single Perl script so I just
>>> download it from its site and put it in ~/bin, as you can see
>>> from my examples.
>>>
>> Hi,
>> I think you would be better off with:
>>
>> youtube-dl --update
> a) Why?
>
> b) How?
>
> $ youtube-dl --update
> Usage: youtube-dl [OPTIONS] URL [URL...]
>
> youtube-dl: error: youtube-dl's self-update mechanism is disabled on Debian.
> Please update youtube-dl using apt(8).
> See https://packages.debian.org/sid/youtube-dl for the latest packaged version.
>
> $
>
>> also:
>>
>>   youtube-dl --help
>>
>> will show all the options.
> … and, of course, --update is missing.
>
> But which of these options did you mean to draw my attention to?
>
> Cheers,
> David.
>
>
HI,

Well, it would appear that I did not use the downlevel version from the 
Debian repository.  If you install from the youtube-dl website and then 
use the --update command you can be sure of having the latest version.

If one uses the --help command the update option will be shown.  I 
didn't know that was missing in the Debian version.

One option that might have helped with a problem that was posted in 
about the last week is the --restrict-filenames option which may prevent 
the need to quote the URL.

Best regards,
Fred

[toc] | [prev] | [next] | [standalone]


#206448

FromGreg Wooledge <wooledg@eeg.ccf.org>
Date2019-03-22 13:10 +0100
Message-ID<xEr9M-7bQ-7@gated-at.bofh.it>
In reply to#206442
On Thu, Mar 21, 2019 at 02:24:08PM -0700, Fred wrote:
> One option that might have helped with a problem that was posted in about
> the last week is the --restrict-filenames option which may prevent the need
> to quote the URL.

No, that won't prevent the need to quote a URL containing & characters.
Those are special to the shell and will cause the command to be split
at that point, becoming two separate commands, one of which will be
executed in the background.

wooledg:~$ echo a&b
[1] 9208
a
bash: b: command not found
[1]+  Done                    echo a
wooledg:~$ 

[toc] | [prev] | [next] | [standalone]


#206451

FromFred <fred@blakemfg.com>
Date2019-03-22 15:20 +0100
Message-ID<xEtbz-8o5-1@gated-at.bofh.it>
In reply to#206448
On 03/22/2019 05:05 AM, Greg Wooledge wrote:
> On Thu, Mar 21, 2019 at 02:24:08PM -0700, Fred wrote:
>> One option that might have helped with a problem that was posted in about
>> the last week is the --restrict-filenames option which may prevent the need
>> to quote the URL.
> No, that won't prevent the need to quote a URL containing & characters.
> Those are special to the shell and will cause the command to be split
> at that point, becoming two separate commands, one of which will be
> executed in the background.
>
> wooledg:~$ echo a&b
> [1] 9208
> a
> bash: b: command not found
> [1]+  Done                    echo a
> wooledg:~$
>
>
Hi,

I realized that after sending the post.  The --restrict-filenames option 
is for the destination file.

Best regards,
Fred

[toc] | [prev] | [next] | [standalone]


#206503

FromDavid Wright <deblis@lionunicorn.co.uk>
Date2019-03-23 02:10 +0100
Message-ID<xEDkB-6aJ-1@gated-at.bofh.it>
In reply to#206442
On Thu 21 Mar 2019 at 14:24:08 (-0700), Fred wrote:
> On 03/21/2019 11:57 AM, David Wright wrote:
> > On Thu 21 Mar 2019 at 10:17:11 (-0700), Fred wrote:
> > > On 03/21/2019 08:41 AM, David Wright wrote:
> > > > On Thu 21 Mar 2019 at 15:38:41 (+0100), Pierre Frenkiel wrote:
> > > > > On Wed, 20 Mar 2019, Celejar wrote:
> > > > > > On Wed, 20 Mar 2019 10:34:42 +0100 (CET) Pierre Frenkiel <pierre.frenkiel@gmail.com> wrote:
> > > > > > > On Tue, 19 Mar 2019, riveravaldez wrote:
> > > > > > > 
> > > > > > > > Maybe worth mentioning: youtube-dl, exceptionally useful and simple CLI tool.
> > > > > > >      useful and simple... but it works only for urls with alphanumeric characters
> > > > > > >      I tried with an url containing ? and &, and I got nothing
> > > > > > >      I tried also by escaping ? and & with \, and it was not better.
> > > > > > >      I'll send you an example later, if you are not convinced...
> > > > > > You can also try putting the url(s) in a file, and feeding the file to
> > > > > > youtube-dl via its -a option.
> > > > > > 
> > > > > > Celejar
> > > > > > 
> > > > >     At last, I fixed everything just by loadind the last version of youtube-dl from the
> > > > >     yt-dl site
> > > > >         wget https://yt-dl.org/latest/youtube-dl -O /usr/local/bin/youtube-dl
> > > > > 
> > > > > after that,  I can do either
> > > > >       youtube-dl --no-playlist  'https://www.youtube.com/watch?v=VQd1IOyhKS4&list=RDEMlHFFKeq-aYlBhg-LtJ-SHw&start_radio=1'
> > > > >       or
> > > > >      youtube-dl https://www.youtube.com/watch?v=VQd1IOyhKS4 both give
> > > > > exactly the same result.
> > > > > 
> > > > > My question is why the Debian version so obsolte ans uneliable?
> > > > The latest version on the website is three days old. The version I
> > > > installed from backports on Jan 28 was 11 days old.
> > > > 
> > > > You have to understand that sites like youtube and the BBC can
> > > > obsolete youtube-dl and get_iplayer overnight, and they do.
> > > > Then some clever people come up with a fix and release a new
> > > > version, and I heave a big sigh of relief and thanks. (Most
> > > > BBC programmes expire after four weeks, and I'm usually two or
> > > > three weeks behind, so a quick fix is vital.)
> > > > 
> > > > Debian mainstream doesn't work to that timetable, so you should
> > > > check out the backports, where those sorts of package appear.
> > > > Fortunately, get_iplayer is a single Perl script so I just
> > > > download it from its site and put it in ~/bin, as you can see
> > > > from my examples.
> > > > 
> > > Hi,
> > > I think you would be better off with:
> > > 
> > > youtube-dl --update
> > a) Why?
> > 
> > b) How?
> > 
> > $ youtube-dl --update
> > Usage: youtube-dl [OPTIONS] URL [URL...]
> > 
> > youtube-dl: error: youtube-dl's self-update mechanism is disabled on Debian.
> > Please update youtube-dl using apt(8).
> > See https://packages.debian.org/sid/youtube-dl for the latest packaged version.
> > 
> > $
> > 
> > > also:
> > > 
> > >   youtube-dl --help
> > > 
> > > will show all the options.
> > … and, of course, --update is missing.
> > 
> > But which of these options did you mean to draw my attention to?

> Well, it would appear that I did not use the downlevel version from
> the Debian repository.  If you install from the youtube-dl website and
> then use the --update command you can be sure of having the latest
> version.

Yes, the very latest. But with backports I get something that's
almost invariably up-to-date enough, and I don't have to check
for upgrades—they just appear, like mainstream updates.

Cheers,
David.

[toc] | [prev] | [next] | [standalone]


#206528

FromPierre Frenkiel <pierre.frenkiel@gmail.com>
Date2019-03-23 20:20 +0100
Message-ID<xEUlr-8ad-1@gated-at.bofh.it>
In reply to#206503
On Fri, 22 Mar 2019, David Wright wrote:

> almost invariably up-to-date enough, and I don't have to check
> for upgradesthey just appear, like mainstream updates.

   what do  you mean by "enough" ?
   why don't use the simple command:

   wget https://yt-dl.org/latest/youtube-dl -O /usr/local/bin/youtube-dl
   chmod 755 /usr/local/bin/youtube-dl

   the debian stretch version is 2018.09.10
   the last one is 2019.03.18
   But the most important is that the command "youtube-dl --update" is then valid,
   and you can put it in a crontab
   An other important feature is that if you have the bad luck to find a bug, you
   can only report it if you use the last version.

best regards,
-- 
Pierre Frenkiel

[toc] | [prev] | [next] | [standalone]


#206544

FromDavid Wright <deblis@lionunicorn.co.uk>
Date2019-03-24 17:10 +0100
Message-ID<xFdR7-3iN-1@gated-at.bofh.it>
In reply to#206528
On Sat 23 Mar 2019 at 20:14:18 (+0100), Pierre Frenkiel wrote:
> On Fri, 22 Mar 2019, David Wright wrote:
> 
> > almost invariably up-to-date enough, and I don't have to check
> > for upgradesthey just appear, like mainstream updates.
> 
>   what do  you mean by "enough" ?

Because it downloads all the videos I'm interested in successfully.
I install software on an as needed basis.

>   why don't use the simple command:
> 
>   wget https://yt-dl.org/latest/youtube-dl -O /usr/local/bin/youtube-dl
>   chmod 755 /usr/local/bin/youtube-dl
> 
>   the debian stretch version is 2018.09.10

I'll do the maths from my previous post, "The version
I installed from backports on Jan 28 was 11 days old",
so it's dated 2019-01-17.

>   the last one is 2019.03.18
>   But the most important is that the command "youtube-dl --update" is then valid,
>   and you can put it in a crontab
>   An other important feature is that if you have the bad luck to find a bug, you
>   can only report it if you use the last version.

Not interested. You're obviously a more serious user, and so your
managing to cope with escaping characters has been a benefit from
this thread. My own concern is how I fit these downloaders into
my workflow patterns. If they're of any benefit to others, fine.
Otherwise ignore them.

Cheers,
David.

[toc] | [prev] | [next] | [standalone]


#206543

FromPierre Frenkiel <pierre.frenkiel@gmail.com>
Date2019-03-24 12:20 +0100
Message-ID<xF9ku-xU-5@gated-at.bofh.it>
In reply to#206412
On Wed, 20 Mar 2019, Celejar wrote:

> On Wed, 20 Mar 2019 10:34:42 +0100 (CET)
> Pierre Frenkiel <pierre.frenkiel@gmail.com> wrote:
>
>> On Tue, 19 Mar 2019, riveravaldez wrote:
>>
>>> Maybe worth mentioning: youtube-dl, exceptionally useful and simple CLI tool.
>>
>>    useful and simple... but it works only for urls with alphanumeric characters
>>    I tried with an url containing ? and &, and I got nothing
>>    I tried also by escaping ? and & with \, and it was not better.
>>    I'll send you an example later, if you are not convinced...
>
> You can also try putting the url(s) in a file, and feeding the file to
> youtube-dl via its -a option.
>
> Celejar
>

    hi Celejar,
    thank you for your suggestion
    After downloading the last version of youtube-dl, I found that escaping
    or quoting actually works: keeping the part after & gives you all the files displayed in the given URL page
    and removing it gives only the requested file.
    Here is a summary of the differents tests I made:

    echo "https://www.youtube.com/watch?v=ELPlMX0glwk&list=PLNNrNEw_ZhtIOOFq-TvyL96AMeuYFoHg_" > t1
    ==> youtube-dl -a t1
        download 99 files

    youtube-dl 'https://www.youtube.com/watch?v=ELPlMX0glwk&list=PLNNrNEw_ZhtIOOFq-TvyL96AMeuYFoHg_'
        download 99 files

    youtube-dl https://www.youtube.com/watch?v=ELPlMX0glwk\&list=PLNNrNEw_ZhtIOOFq-TvyL96AMeuYFoHg_
        download 99 files

    youtube-dl --no-playlist https://www.youtube.com/watch?v=ELPlMX0glwk\&list=PLNNrNEw_ZhtIOOFq-TvyL96AMeuYFoHg_
        download 1 file

    ==> youtube-dl --no-playlist -a t1
        download 1 file

    youtube-dl https://www.youtube.com/watch?v=ELPlMX0glwk
        download 1 file

best regards,
-- 
Pierre Frenkiel

[toc] | [prev] | [standalone]


Page 2 of 2 — ← Prev page 1 [2]

Back to top | Article view | linux.debian.user


csiph-web